summaryrefslogtreecommitdiff
path: root/src/mongo/db/index/index_descriptor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/index/index_descriptor.h')
-rw-r--r--src/mongo/db/index/index_descriptor.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/index/index_descriptor.h b/src/mongo/db/index/index_descriptor.h
index b3eb54aa6b1..ce1bb344644 100644
--- a/src/mongo/db/index/index_descriptor.h
+++ b/src/mongo/db/index/index_descriptor.h
@@ -141,13 +141,13 @@ namespace mongo {
// Allow access to arbitrary fields in the per-index info object. Some indices stash
// index-specific data there.
- BSONElement getInfoElement(const string& name) const { return _infoObj[name]; }
+ BSONElement getInfoElement(const std::string& name) const { return _infoObj[name]; }
//
// "Internals" of accessing the index, used by IndexAccessMethod(s).
//
// Return a (rather compact) string representation.
std::string toString() const { _checkOk(); return _infoObj.toString(); }
// Return the info object.
@@ -171,7 +171,7 @@ namespace mongo {
return i.next().eoo();
}
- static string makeIndexNamespace( const StringData& ns,
+ static std::string makeIndexNamespace( const StringData& ns,
const StringData& name ) {
return ns.toString() + ".$" + name.toString();
}
@@ -141,13 +141,13 @@ namespace mongo {
// "Internals" of accessing the index, used by IndexAccessMethod(s).
//
- // Return a (rather compact) string representation.
+ // Return a (rather compact) std::string representation.
std::string toString() const { _checkOk(); return _infoObj.toString(); }
// Return the info object.